@@ -87,11 +87,10 @@ def remove(path):
             info("remove %s" % path)
 
 
-def create_logger(logger_name, log_file):
-    logger = logging.getLogger(logger_name)
-    logger.setLevel(logging.INFO)
-    log_file_handler = logging.FileHandler(log_file, mode='w')
+def create_logger(log_file):
     logging.basicConfig(filename=log_file, format="%(asctime)-15s %(message)s")
-    logger.addHandler(log_file_handler)
-    logger.addHandler(logging.StreamHandler())
+    logger = logging.getLogger()
+    logger.setLevel(logging.INFO)
+    console = logging.StreamHandler()
+    logging.getLogger('').addHandler(console)
     return logger
